aboutsummaryrefslogtreecommitdiff
path: root/lib/vtls/vtls.c
diff options
context:
space:
mode:
authorAntoine Aubert <a.aubert@overkiz.com>2017-01-20 08:10:28 +0100
committerDaniel Stenberg <daniel@haxx.se>2017-01-20 08:31:03 +0100
commit06b1197eeb6425ae297a5fad9ed65f09e9cf51d0 (patch)
treee1f080c214525902c7f521269f05d98920e4a9ad /lib/vtls/vtls.c
parent6b7616690e5370c21e3a760321af6bf4edbabfb6 (diff)
vtls: fix mbedtls multi non blocking handshake.
When using multi, mbedtls handshake is in non blocking mode. vtls must set wait for read/write flags for the socket. Closes #1223
Diffstat (limited to 'lib/vtls/vtls.c')
-rw-r--r--lib/vtls/vtls.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/lib/vtls/vtls.c b/lib/vtls/vtls.c
index fad9335bb..871622fef 100644
--- a/lib/vtls/vtls.c
+++ b/lib/vtls/vtls.c
@@ -485,8 +485,9 @@ void Curl_ssl_close_all(struct Curl_easy *data)
}
#if defined(USE_OPENSSL) || defined(USE_GNUTLS) || defined(USE_SCHANNEL) || \
- defined(USE_DARWINSSL) || defined(USE_NSS)
-/* This function is for OpenSSL, GnuTLS, darwinssl, and schannel only. */
+ defined(USE_DARWINSSL) || defined(USE_NSS) || defined(USE_MBEDTLS)
+/* This function is for OpenSSL, GnuTLS, darwinssl, mbedtls, and schannel
+ only. */
int Curl_ssl_getsock(struct connectdata *conn, curl_socket_t *socks,
int numsocks)
{